==> zio-aws-iotthingsgraph_3-5.17.124.2-sources.jar: zio/aws/iotthingsgraph/model/SearchSystemTemplatesResponse.scala <==
package zio.aws.iotthingsgraph.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotthingsgraph.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class SearchSystemTemplatesResponse(
    summaries: Option[
      Iterable[zio.aws.iotthingsgraph.model.SystemTemplateSummary]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse = {
    import SearchSystemTemplatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
      .builder()
      .optionallyWith(
        summaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.summaries)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly =
    zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse
      .wrap(buildAwsValue())
}
object SearchSystemTemplatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse =
      zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse(
        summaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def summaries: Option[
      List[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    ]
    def nextToken: Option[NextToken]
    def getSummaries: ZIO[Any, AwsError, List[
      zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("summaries", summaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ) extends zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly {
    override val summaries: Option[
      List[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    ] = scala
      .Option(impl.summaries())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iotthingsgraph.model.SystemTemplateSummary.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iotthingsgraph.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ): zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotthingsgraph_3-5.17.206.1-sources.jar: zio/aws/iotthingsgraph/model/SearchSystemTemplatesResponse.scala <==
package zio.aws.iotthingsgraph.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotthingsgraph.model.primitives.NextToken
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SearchSystemTemplatesResponse(
    summaries: Optional[
      Iterable[zio.aws.iotthingsgraph.model.SystemTemplateSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse = {
    import SearchSystemTemplatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
      .builder()
      .optionallyWith(
        summaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.summaries)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly =
    zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse
      .wrap(buildAwsValue())
}
object SearchSystemTemplatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse =
      zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse(
        summaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def summaries: Optional[
      List[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getSummaries: ZIO[Any, AwsError, List[
      zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("summaries", summaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ) extends zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly {
    override val summaries: Optional[
      List[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.summaries())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iotthingsgraph.model.SystemTemplateSummary.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iotthingsgraph.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.SearchSystemTemplatesResponse
  ): zio.aws.iotthingsgraph.model.SearchSystemTemplatesResponse.ReadOnly =
    new Wrapper(impl)
}
